@@ -13,7 +13,7 @@ use AnyEvent::WebSocket::Connection;
 use PerlX::Maybe qw( maybe provided );
 
 # ABSTRACT: WebSocket client for AnyEvent
-our $VERSION = '0.11_02'; # VERSION
+our $VERSION = '0.11_03'; # VERSION
 
 
 has timeout => (
@@ -151,11 +151,11 @@ AnyEvent::WebSocket::Client - WebSocket client for AnyEvent
 
 =head1 VERSION
 
-version 0.11_02
+version 0.11_03
 
 =head1 SYNOPSIS
 
- use AnyEvent::WebSocket::Client;
+ use AnyEvent::WebSocket::Client 0.12;
  
  my $client = AnyEvent::WebSocket::Client->new;
  
@@ -197,6 +197,11 @@ L<Protocol::WebSocket> rather than reinventing the wheel.  You could use
 L<AnyEvent> and L<Protocol::WebSocket> directly if you wanted finer grain
 control, but if that is not necessary then this class may save you some time.
 
+The recommended API was added to the L<AnyEvent::WebSocket::Connection>
+class with version 0.12, so it is recommended that you include that version
+when using this module.  The older API will continue to work for now with
+deprecation warnings.
+
 =head1 ATTRIBUTES
 
 =head2 timeout
